@@ -222,9 +222,9 @@ class Reporter(object):
                     </td>
                     <td>
                         <table border='1' align='center' cellpadding=3 cellspacing=3 style='border-collapse: collapse' width='425'>
-                            <tr  bgcolor='%s'>
+                            <tr style='font-size: 18'  bgcolor='%s'>
                                 <td>
-                                    <font color='#2850A5'>&nbsp; Report Generate Time</font>
+                                    <font color='#2850A5'>&nbsp; Report Generation Time</font>
                                 </td>
                                 <td width='180' align='center'>
                                     <font color='#2850A5'>%s</font>
@@ -232,7 +232,7 @@ class Reporter(object):
                             </tr>
                             <tr>
                                 <td>
-                                    <font color='#2850A5'> &nbsp; Total Execution Time</font>
+                                    <font color='#2850A5'> &nbsp; Total Execution Duration</font>
                                 </td>
                                 <td width='150' align='center'><font color='#2850A5'>%s (Seconds)</font>
                                 </td>
@@ -387,7 +387,7 @@ class Reporter(object):
                         </td>
                         <td width='150' align='center'>
                             <b>
-                                <font color='#A52812'>Execution Time</font>
+                                <font color='#A52812'>Execution Duration(Seconds)</font>
                             </b>
                         </td>
                     </tr>
@@ -510,7 +510,7 @@ class Reporter(object):
                         </td>
                         <td width='150' align='center'>
                             <b>
-                                <font color='#2850A5'>Execution Time</font>
+                                <font color='#2850A5'>Execution Duration(Seconds)</font>
                             </b>
                         </td>
                     </tr>
